@@ -116,7 +116,8 @@ class ClassificationDataset(Dataset):
             raise KeyError(f"mode({mode}) is not a valid split name")
         # Load data features from cache or dataset file
         cached_features_file = os.path.join(
-            args.data_cache_dir,
+            args.downstream_corpus_root_dir,
+            args.downstream_corpus_name,
             "cached_{}_{}_{}_{}_{}".format(
                 mode,
                 tokenizer.__class__.__name__,
@@ -138,8 +139,12 @@ class ClassificationDataset(Dataset):
                     f"Loading features from cached file {cached_features_file} [took %.3f s]", time.time() - start
                 )
             else:
-                logger.info(f"Creating features from dataset file at {args.downstream_corpus_dir}")
-                corpus_fpath = os.path.join(args.downstream_corpus_dir, f"{mode}.txt")
+                corpus_fpath = os.path.join(
+                    args.downstream_corpus_root_dir,
+                    args.downstream_corpus_name,
+                    f"ratings_{mode}.txt"
+                )
+                logger.info(f"Creating features from dataset file at {corpus_fpath}")
                 examples = self.corpus.get_examples(corpus_fpath, mode)
                 self.features = convert_examples_to_features_fn(
                     examples,
